# hecstac
[![CI](https://github.com/dewberry/hecstac/actions/workflows/ci.yaml/badge.svg?branch=main)](https://github.com/dewberry/hecstac/actions/workflows/ci.yaml)
[![Documentation Status](https://readthedocs.org/projects/hecstac/badge/?version=latest)](https://hecstac.readthedocs.io/en/latest/?badge=latest)
[![Release](https://github.com/dewberry/hecstac/actions/workflows/release.yaml/badge.svg)](https://github.com/dewberry/hecstac/actions/workflows/release.yaml)
[![PyPI version](https://badge.fury.io/py/hecstac.svg)](https://badge.fury.io/py/hecstac)

Utilities for creating STAC items from HEC models

**hecstac** is an open-source Python library designed to mine metadata from HEC model simulations for use in the development of catalogs documenting probabilistic flood studies. This project automates the generation of STAC Items and Assets from HEC-HMS and HEC-RAS model files, enabling improved data and metadata management. 

